@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2022 Google LLC. All Rights Reserved.
+# Copyright 2024 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -48,24 +48,6 @@ class SpokesClient(object):
             name=spoke_ref.RelativeName()))
     return self.spoke_service.Deactivate(deactivate_req)
 
-  def Accept(self, spoke_ref):
-    """Call API to activate an existing spoke."""
-    accept_req = (
-        self.messages.NetworkconnectivityProjectsLocationsSpokesAcceptRequest(
-            name=spoke_ref.RelativeName()))
-    return self.spoke_service.Accept(accept_req)
-
-  def Reject(self, spoke_ref, rejection_details):
-    """Call API to reject an existing spoke."""
-    rejection_detailed_req = self.messages.RejectSpokeRequest(
-        details=rejection_details)
-    reject_req = (
-        self.messages
-        .NetworkconnectivityProjectsLocationsSpokesRejectRequest(
-            name=spoke_ref.RelativeName(),
-            rejectSpokeRequest=rejection_detailed_req))
-    return self.spoke_service.Reject(reject_req)
-
   def Delete(self, spoke_ref):
     """Call API to delete an existing spoke."""
     delete_req = (
@@ -102,7 +84,7 @@ class SpokesClient(object):
         limit=limit,
         batch_size_attribute='pageSize')
 
-  def CreateVPCSpoke(self, spoke_ref, spoke, request_id=None):
+  def CreateSpoke(self, spoke_ref, spoke, request_id=None):
     """Call API to create a new spoke."""
     parent = spoke_ref.Parent().RelativeName()
     spoke_id = spoke_ref.Name()
@@ -112,7 +94,7 @@ class SpokesClient(object):
             parent=parent, requestId=request_id, spoke=spoke, spokeId=spoke_id))
     return self.spoke_service.Create(create_req)
 
-  def UpdateVPCSpoke(self, spoke_ref, spoke, update_mask, request_id=None):
+  def UpdateSpoke(self, spoke_ref, spoke, update_mask, request_id=None):
     """Call API to update a existing spoke."""
     name = spoke_ref.RelativeName()
     update_mask_string = ','.join(update_mask)
@@ -134,6 +116,7 @@ class HubsClient(object):
     self.client = networkconnectivity_util.GetClientInstance(release_track)
     self.messages = networkconnectivity_util.GetMessagesModule(release_track)
     self.hub_service = self.client.projects_locations_global_hubs
+    self.operation_service = self.client.projects_locations_operations
 
   def ListHubSpokes(
       self,
@@ -167,3 +150,52 @@ class HubsClient(object):
         batch_size_attribute='pageSize',
         method='ListSpokes'
     )
+
+  def AcceptSpoke(self, hub_ref, spoke):
+    """Call API to accept a spoke into a hub."""
+    accept_hub_spoke_req = self.messages.AcceptHubSpokeRequest(
+        spokeUri=spoke)
+    accept_req = (
+        self.messages.NetworkconnectivityProjectsLocationsGlobalHubsAcceptSpokeRequest(
+            name=hub_ref.RelativeName(), acceptHubSpokeRequest=accept_hub_spoke_req))
+    return self.hub_service.AcceptSpoke(accept_req)
+
+  def RejectSpoke(self, hub_ref, spoke, details):
+    """Call API to reject a spoke from a hub."""
+    reject_hub_spoke_req = self.messages.RejectHubSpokeRequest(spokeUri=spoke, details=details)
+    reject_req = (
+        self.messages.NetworkconnectivityProjectsLocationsGlobalHubsRejectSpokeRequest(
+            name=hub_ref.RelativeName(), rejectHubSpokeRequest=reject_hub_spoke_req))
+    return self.hub_service.RejectSpoke(reject_req)
+
+
+class GroupsClient(object):
+  """Client for group service in network connectivity API."""
+
+  def __init__(self, release_track=base.ReleaseTrack.GA):
+    self.release_track = release_track
+    self.client = networkconnectivity_util.GetClientInstance(release_track)
+    self.messages = networkconnectivity_util.GetMessagesModule(release_track)
+    self.group_service = self.client.projects_locations_global_hubs_groups
+    self.operation_service = self.client.projects_locations_operations
+
+  def UpdateGroup(self, group_ref, group, update_mask, request_id=None):
+    """Call API to update an existing group."""
+    name = group_ref.RelativeName()
+    update_mask_string = ','.join(update_mask)
+
+    update_req = (
+        self.messages.NetworkconnectivityProjectsLocationsGlobalHubsGroupsPatchRequest(
+            name=name,
+            requestId=request_id,
+            group=group,
+            updateMask=update_mask_string))
+    return self.group_service.Patch(update_req)
+
+  def Get(self, group_ref):
+    """Call API to get an existing group."""
+    get_req = (
+        self.messages.NetworkconnectivityProjectsLocationsGlobalHubsGroupsGetRequest(
+            name=group_ref.RelativeName()))
+    return self.group_service.Get(get_req)
+
