@@ -614,8 +614,8 @@ def AddSrcNetworkScope(parser, required=False):
           'Use this flag to indicate that the rule should match internet,'
           ' non-internet traffic or traffic coming from the network specified'
           ' by --src-network. It applies to ingress rules. Valid values are'
-          ' INTERNET, NON_INTERNET and VPC_NETWORKS. Use empty string to clear'
-          ' the field.'
+          ' INTERNET, NON_INTERNET, VPC_NETWORKS and INTRA_VPC. Use empty'
+          ' string to clear the field.'
       ),
   )
 
@@ -643,7 +643,7 @@ def AddDestNetworkScope(parser, required=False):
       help=(
           'Use this flag to indicate that the rule should match internet or'
           ' non-internet traffic. It applies to destination traffic for egress'
-          ' rules. Valid values are INTERNET and NON_INTERNET. Use empty string'
-          ' to clear the field.'
+          ' rules. Valid values are INTERNET, NON_INTERNET and INTRA_VPC. Use'
+          ' empty string to clear the field.'
       ),
   )
