@@ -470,7 +470,7 @@ def AddBigQueryConfigFlags(
   )
 
 
-def AddCloudStorageConfigFlags(parser, is_update, enable_use_topic_schema):
+def AddCloudStorageConfigFlags(parser, is_update):
   """Adds Cloud Storage config flags to parser."""
   current_group = parser
   cloud_storage_config_group_help = """Cloud Storage Config Options. The Cloud
@@ -578,20 +578,18 @@ def AddCloudStorageConfigFlags(parser, is_update, enable_use_topic_schema):
           ' --cloud-storage-output-format=avro.'
       ),
   )
-  if enable_use_topic_schema:
-    AddBooleanFlag(
-        parser=cloud_storage_config_group,
-        flag_name='cloud-storage-use-topic-schema',
-        action='store_true',
-        default=None,
-        hidden=True,
-        help_text=(
-            "Whether or not to use the schema for the subscription's topic (if"
-            ' it exists) when writing messages to Cloud Storage. This has an'
-            ' effect only for subscriptions with'
-            ' --cloud-storage-output-format=avro.'
-        ),
-    )
+  AddBooleanFlag(
+      parser=cloud_storage_config_group,
+      flag_name='cloud-storage-use-topic-schema',
+      action='store_true',
+      default=None,
+      help_text=(
+          "Whether or not to use the schema for the subscription's topic (if"
+          ' it exists) when writing messages to Cloud Storage. This has an'
+          ' effect only for subscriptions with'
+          ' --cloud-storage-output-format=avro.'
+      ),
+  )
   cloud_storage_config_group.add_argument(
       '--cloud-storage-service-account-email',
       default=None,
@@ -667,7 +665,6 @@ def AddSubscriptionSettingsFlags(
     parser,
     is_update=False,
     enable_push_to_cps=False,
-    enable_cloud_storage_use_topic_schema=False,
 ):
   """Adds the flags for creating or updating a subscription.
 
@@ -676,8 +673,6 @@ def AddSubscriptionSettingsFlags(
     is_update: Whether or not this is for the update operation (vs. create).
     enable_push_to_cps: whether or not to enable Pubsub Export config flags
       support.
-    enable_cloud_storage_use_topic_schema: whether or not to enable Cloud
-      Storage use topic schema field flag support.
   """
   AddAckDeadlineFlag(parser)
   AddPushConfigFlags(
@@ -687,9 +682,7 @@ def AddSubscriptionSettingsFlags(
 
   mutex_group = parser.add_mutually_exclusive_group()
   AddBigQueryConfigFlags(mutex_group, is_update)
-  AddCloudStorageConfigFlags(
-      mutex_group, is_update, enable_cloud_storage_use_topic_schema
-  )
+  AddCloudStorageConfigFlags(mutex_group, is_update)
   if enable_push_to_cps:
     AddPubsubExportConfigFlags(mutex_group, is_update)
   AddSubscriptionMessageRetentionFlags(parser, is_update)
