@@ -22,8 +22,8 @@ import json
 import re
 
 from googlecloudsdk.api_lib.util import exceptions as exceptions_util
+from googlecloudsdk.calliope import exceptions as c_exceptions
 from googlecloudsdk.core import exceptions
-
 import six
 
 
@@ -75,6 +75,10 @@ class ExecutionNotFoundError(exceptions.Error):
   """Indicates that a provided execution name was not found."""
 
 
+class WorkerNotFoundError(exceptions.Error):
+  """Indicates that a provided worker name was not found."""
+
+
 class DockerVersionError(exceptions.Error):
   """Indicates an error in determining the docker version."""
 
@@ -290,3 +294,15 @@ class InvalidRuntimeLanguage(exceptions.Error):
     super(InvalidRuntimeLanguage, self).__init__(
         f'Runtime language [{invalid_runtime}] is not supported'
     )
+
+
+class RequiredImageArgumentException(c_exceptions.RequiredArgumentException):
+  """An exception for missing image flag for containers."""
+
+  def __init__(self, containers):
+    super(RequiredImageArgumentException, self).__init__(
+        '--image',
+        'Containers {} require a container image to deploy.'.format(
+            ', '.join(containers)
+        ),
+    )
