@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2023 Google LLC
+# Copyright 2024 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,11 +21,14 @@ from .content import (
     Content,
     FileData,
     GenerationConfig,
+    GroundingChunk,
     GroundingMetadata,
+    GroundingSupport,
     Part,
     SafetyRating,
     SafetySetting,
     SearchEntryPoint,
+    Segment,
     VideoMetadata,
     HarmCategory,
 )
@@ -123,11 +126,14 @@ __all__ = (
     'Content',
     'FileData',
     'GenerationConfig',
+    'GroundingChunk',
     'GroundingMetadata',
+    'GroundingSupport',
     'Part',
     'SafetyRating',
     'SafetySetting',
     'SearchEntryPoint',
+    'Segment',
     'VideoMetadata',
     'HarmCategory',
     'Attribution',
