@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2023 Google LLC
+# Copyright 2024 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -726,21 +726,38 @@ class CountTokensRequest(proto.Message):
     r"""Request message for
     [PredictionService.CountTokens][google.cloud.aiplatform.v1beta1.PredictionService.CountTokens].
 
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         endpoint (str):
             Required. The name of the Endpoint requested to perform
             token counting. Format:
             ``projects/{project}/locations/{location}/endpoints/{endpoint}``
         model (str):
-            Required. The name of the publisher model requested to serve
+            Optional. The name of the publisher model requested to serve
             the prediction. Format:
             ``projects/{project}/locations/{location}/publishers/*/models/*``
         instances (MutableSequence[google.protobuf.struct_pb2.Value]):
-            Required. The instances that are the input to
+            Optional. The instances that are the input to
             token counting call. Schema is identical to the
             prediction schema of the underlying model.
         contents (MutableSequence[googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.Content]):
-            Required. Input content.
+            Optional. Input content.
+        system_instruction (googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.Content):
+            Optional. The user provided system
+            instructions for the model. Note: only text
+            should be used in parts and content in each part
+            will be in a separate paragraph.
+
+            This field is a member of `oneof`_ ``_system_instruction``.
+        tools (MutableSequence[googlecloudsdk.generated_clients.gapic_clients.aiplatform_v1beta1.types.Tool]):
+            Optional. A list of ``Tools`` the model may use to generate
+            the next response.
+
+            A ``Tool`` is a piece of code that enables the system to
+            interact with external systems to perform an action, or set
+            of actions, outside of knowledge and scope of the model.
     """
 
     endpoint: str = proto.Field(
@@ -761,6 +778,17 @@ class CountTokensRequest(proto.Message):
         number=4,
         message=content.Content,
     )
+    system_instruction: content.Content = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        optional=True,
+        message=content.Content,
+    )
+    tools: MutableSequence[tool.Tool] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=6,
+        message=tool.Tool,
+    )
 
 
 class CountTokensResponse(proto.Message):
