@@ -31,38 +31,33 @@ def _DetailedHelp():
           'Create a TCP health check to monitor load balanced instances.',
       'DESCRIPTION':
           """\
-          *{command}* is used to create a TCP health check. TCP health checks
-          monitor instances in a load balancer controlled by a target pool. All
-          arguments to the command are optional except for the name of the
-          health check. For more information on load balancing, see
-          [](https://cloud.google.com/compute/docs/load-balancing-and-autoscaling/)
+          *{command}* is used to create a non-legacy health check using the TCP
+          protocol. You can use this health check for Google Cloud
+          load balancers or for managed instance group autohealing. For more
+          information, see the health checks overview at:
+          [](https://cloud.google.com/load-balancing/docs/health-check-concepts)
           """,
   }
 
 
-def _Args(parser, include_l7_internal_load_balancing, include_log_config):
+def _Args(parser, include_log_config, include_source_regions):
   """Set up arguments to create an HTTP2 HealthCheck."""
   parser.display_info.AddFormat(flags.DEFAULT_LIST_FORMAT)
-  flags.HealthCheckArgument(
-      'TCP',
-      include_l7_internal_load_balancing=include_l7_internal_load_balancing
-  ).AddArgument(
-      parser, operation_type='create')
+  flags.HealthCheckArgument('TCP').AddArgument(parser, operation_type='create')
   health_checks_utils.AddTcpRelatedCreationArgs(parser)
   health_checks_utils.AddProtocolAgnosticCreationArgs(parser, 'TCP')
+  if include_source_regions:
+    health_checks_utils.AddHealthCheckSourceRegionsRelatedArgs(parser)
   if include_log_config:
     health_checks_utils.AddHealthCheckLoggingRelatedArgs(parser)
 
 
-def _Run(args, holder, include_l7_internal_load_balancing, include_log_config):
+def _Run(args, holder, include_log_config, include_source_regions):
   """Issues the request necessary for adding the health check."""
   client = holder.client
   messages = client.messages
 
-  health_check_ref = flags.HealthCheckArgument(
-      'TCP',
-      include_l7_internal_load_balancing=include_l7_internal_load_balancing
-  ).ResolveAsResource(
+  health_check_ref = flags.HealthCheckArgument('TCP').ResolveAsResource(
       args, holder.resources, default_scope=compute_scope.ScopeEnum.GLOBAL)
   proxy_header = messages.TCPHealthCheck.ProxyHeaderValueValuesEnum(
       args.proxy_header)
@@ -108,29 +103,38 @@ def _Run(args, holder, include_l7_internal_load_balancing, include_log_config):
     request.healthCheck.logConfig = health_checks_utils.CreateLogConfig(
         client, args)
 
+  if include_source_regions and (args.source_regions is not None):
+    request.healthCheck.sourceRegions = args.source_regions
+
   return client.MakeRequests([(collection, 'Insert', request)])
 
 
-@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.GA)
+@base.ReleaseTracks(base.ReleaseTrack.GA)
 class Create(base.CreateCommand):
   """Create a TCP health."""
 
-  _include_l7_internal_load_balancing = True
-  _include_log_config = False
+  _include_log_config = True
+  _include_source_regions = False
   detailed_help = _DetailedHelp()
 
   @classmethod
   def Args(cls, parser):
-    _Args(parser, cls._include_l7_internal_load_balancing,
-          cls._include_log_config)
+    _Args(parser, cls._include_log_config, cls._include_source_regions)
 
   def Run(self, args):
     holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
-    return _Run(args, holder, self._include_l7_internal_load_balancing,
-                self._include_log_config)
+    return _Run(
+        args, holder, self._include_log_config, self._include_source_regions
+    )
+
+
+@base.ReleaseTracks(base.ReleaseTrack.BETA)
+class CreateBeta(Create):
+
+  _include_source_regions = True
 
 
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
-class CreateAlpha(Create):
+class CreateAlpha(CreateBeta):
 
-  _include_log_config = True
+  _include_source_regions = True
