@@ -20,10 +20,10 @@ from __future__ import unicode_literals
 
 from googlecloudsdk.api_lib.container.fleet import util
 from googlecloudsdk.calliope import actions
-from googlecloudsdk.calliope import base as calliope_base
+from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.anthos.common import file_parsers
 from googlecloudsdk.command_lib.container.fleet import resources
-from googlecloudsdk.command_lib.container.fleet.features import base
+from googlecloudsdk.command_lib.container.fleet.features import base as features_base
 from googlecloudsdk.command_lib.container.fleet.mesh import utils
 
 
@@ -46,7 +46,9 @@ def _RunUpdate(cmd, args):
     update_mask = ['membershipSpecs']
   elif args.fleet_default_member_config is None:
     resource = True
-    memberships = base.ParseMembershipsPlural(args, prompt=True, search=True)
+    memberships = features_base.ParseMembershipsPlural(
+        args, prompt=True, search=True
+    )
     update_mask = ['membershipSpecs']
 
   f = cmd.GetFeature()
@@ -57,8 +59,10 @@ def _RunUpdate(cmd, args):
     patch = cmd.messages.MembershipFeatureSpec()
 
     for name, spec in cmd.hubclient.ToPyDict(f.membershipSpecs).items():
-      if util.MembershipShortname(name) == util.MembershipShortname(
-          membership) and spec:
+      if (
+          util.MembershipShortname(name) == util.MembershipShortname(membership)
+          and spec
+      ):
         patch = spec
     if not patch.mesh:
       patch.mesh = cmd.messages.ServiceMeshMembershipSpec()
@@ -72,27 +76,56 @@ def _RunUpdate(cmd, args):
     if hasattr(args, 'management') and args.management is not None:
       management = (
           cmd.messages.ServiceMeshMembershipSpec.ManagementValueValuesEnum(
-              'MANAGEMENT_MANUAL'))
+              'MANAGEMENT_MANUAL'
+          )
+      )
       if args.management == 'automatic':
         management = (
             cmd.messages.ServiceMeshMembershipSpec.ManagementValueValuesEnum(
-                'MANAGEMENT_AUTOMATIC'))
+                'MANAGEMENT_AUTOMATIC'
+            )
+        )
       patch.mesh.management = management
 
     if args.control_plane is not None:
       control_plane = (
           cmd.messages.ServiceMeshMembershipSpec.ControlPlaneValueValuesEnum(
-              'MANUAL'))
+              'MANUAL'
+          )
+      )
       if args.control_plane == 'automatic':
         control_plane = (
             cmd.messages.ServiceMeshMembershipSpec.ControlPlaneValueValuesEnum(
-                'AUTOMATIC'))
+                'AUTOMATIC'
+            )
+        )
       patch.mesh.controlPlane = control_plane
 
+    if hasattr(args, 'config_api') and args.config_api is not None:
+      config_api = (
+          cmd.messages.ServiceMeshMembershipSpec.ConfigApiValueValuesEnum(
+              'CONFIG_API_UNSPECIFIED'
+          )
+      )
+      if args.config_api == 'istio':
+        config_api = (
+            cmd.messages.ServiceMeshMembershipSpec.ConfigApiValueValuesEnum(
+                'CONFIG_API_ISTIO'
+            )
+        )
+      if args.config_api == 'gateway':
+        config_api = (
+            cmd.messages.ServiceMeshMembershipSpec.ConfigApiValueValuesEnum(
+                'CONFIG_API_GATEWAY'
+            )
+        )
+      patch.mesh.configApi = config_api
+
     membership_specs[membership] = patch
 
   f = cmd.messages.Feature(
-      membershipSpecs=cmd.hubclient.ToMembershipSpecs(membership_specs))
+      membershipSpecs=cmd.hubclient.ToMembershipSpecs(membership_specs)
+  )
 
   if args.fleet_default_member_config:
     # Load config YAML file.
@@ -113,8 +146,9 @@ def _RunUpdate(cmd, args):
   cmd.Update(update_mask, f)
 
 
-@calliope_base.ReleaseTracks(calliope_base.ReleaseTrack.ALPHA)
-class UpdateAlpha(base.UpdateCommand):
+@base.DefaultUniverseOnly
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+class UpdateAlpha(features_base.UpdateCommand):
   """Update the configuration of the Service Mesh Feature.
 
   Update the Service Mesh Feature Spec of a membership.
@@ -136,7 +170,6 @@ class UpdateAlpha(base.UpdateCommand):
 
     args_group.add_argument(
         '--fleet-default-member-config',
-        hidden=True,
         type=str,
         help="""The path to a service-mesh.yaml configuration file.
 
@@ -146,14 +179,18 @@ class UpdateAlpha(base.UpdateCommand):
           $ {command} --fleet-default-member-config=/path/to/service-mesh.yaml""",
     )
 
-    membership_group = args_group.add_group()
+    membership_group = args_group.add_group(
+        'Component options',
+    )
 
     membership_names_group = membership_group.add_mutually_exclusive_group()
     resources.AddMembershipResourceArg(
         membership_names_group,
         plural=True,
-        membership_help=('Membership names to update, separated by commas if '
-                         'multiple are supplied.'),
+        membership_help=(
+            'Membership names to update, separated by commas if '
+            'multiple are supplied.'
+        ),
     )
     membership_names_group.add_argument(
         '--membership',
@@ -161,39 +198,56 @@ class UpdateAlpha(base.UpdateCommand):
         help='Membership name to update.',
         action=actions.DeprecationAction(
             '--membership',
-            warn='The {flag_name} flag is now '
-            'deprecated. Please use `--memberships` '
-            'instead.'))
+            warn=(
+                'The {flag_name} flag is now '
+                'deprecated. Please use `--memberships` '
+                'instead.'
+            ),
+        ),
+    )
 
-    membership_configs_group = membership_group.add_group(required=True)
-    membership_configs_group.add_argument(
+    membership_config_group = membership_group.add_group(required=True)
+    membership_config_group.add_argument(
         '--origin',
-        hidden=True,
         choices=['fleet'],
         help='Changing the origin of the membership.',
     )
-    membership_configs_group.add_argument(
+    membership_controlplane_group = (
+        membership_config_group.add_mutually_exclusive_group()
+    )
+
+    membership_controlplane_group.add_argument(
+        '--config-api',
+        choices=['istio', 'gateway'],
+        help='The API to use for mesh configuration.',
+    )
+    membership_controlplane_group.add_argument(
         '--management',
         choices=['automatic', 'manual'],
         help='The management mode to update to.',
     )
-    membership_configs_group.add_argument(
+    membership_controlplane_group.add_argument(
         '--control-plane',
         choices=['automatic', 'manual'],
         help='Control plane management to update to.',
         action=actions.DeprecationAction(
             '--control-plane',
-            warn='The {flag_name} flag is now '
-            'deprecated. Please use `--management` '
-            'instead. '
-            'See https://cloud.google.com/service-mesh/docs/managed/provision-managed-anthos-service-mesh'))
+            warn=(
+                'The {flag_name} flag is now '
+                'deprecated. Please use `--management` '
+                'instead. '
+                'See https://cloud.google.com/service-mesh/docs/managed/provision-managed-anthos-service-mesh'
+            ),
+        ),
+    )
 
   def Run(self, args):
     _RunUpdate(self, args)
 
 
-@calliope_base.ReleaseTracks(calliope_base.ReleaseTrack.GA)
-class UpdateGA(base.UpdateCommand):
+@base.DefaultUniverseOnly
+@base.ReleaseTracks(base.ReleaseTrack.GA)
+class UpdateGA(features_base.UpdateCommand):
   """Update the configuration of the Service Mesh Feature.
 
   Update the Service Mesh Feature Spec of a Membership.
@@ -215,7 +269,6 @@ class UpdateGA(base.UpdateCommand):
 
     args_group.add_argument(
         '--fleet-default-member-config',
-        hidden=True,
         type=str,
         help="""The path to a service-mesh.yaml configuration file.
 
@@ -231,14 +284,15 @@ class UpdateGA(base.UpdateCommand):
     resources.AddMembershipResourceArg(
         membership_names_group,
         plural=True,
-        membership_help=('Membership names to update, separated by commas if '
-                         'multiple are supplied.'),
+        membership_help=(
+            'Membership names to update, separated by commas if '
+            'multiple are supplied.'
+        ),
     )
 
     membership_configs_group = membership_group.add_group(required=True)
     membership_configs_group.add_argument(
         '--origin',
-        hidden=True,
         choices=['fleet'],
         help='Changing the origin of the membership.',
     )
@@ -253,10 +307,14 @@ class UpdateGA(base.UpdateCommand):
         help='Control plane management to update to.',
         action=actions.DeprecationAction(
             '--control-plane',
-            warn='The {flag_name} flag is now '
-            'deprecated. Please use `--management` '
-            'instead. '
-            'See https://cloud.google.com/service-mesh/docs/managed/provision-managed-anthos-service-mesh'))
+            warn=(
+                'The {flag_name} flag is now '
+                'deprecated. Please use `--management` '
+                'instead. '
+                'See https://cloud.google.com/service-mesh/docs/managed/provision-managed-anthos-service-mesh'
+            ),
+        ),
+    )
 
   def Run(self, args):
     _RunUpdate(self, args)
