@@ -18,6 +18,7 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
 
+from googlecloudsdk.calliope import arg_parsers
 from googlecloudsdk.calliope import base
 
 
@@ -28,3 +29,15 @@ class SparkApplications(base.Group):
   """Submit Dataproc GDC Spark Applications."""
 
   category = base.DATA_ANALYTICS_CATEGORY
+
+  @staticmethod
+  def Args(parser):
+    parser.add_argument(
+        '--dependency-images',
+        help=(
+            'Comma separated list of images containing dependencies for the'
+            ' Spark Application.'
+        ),
+        metavar='IMAGE',
+        type=arg_parsers.ArgList(),
+    )
