@@ -22,11 +22,15 @@ from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.iap import util as iap_util
 
 
+@base.ReleaseTracks(
+    base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA, base.ReleaseTrack.GA
+)
+@base.DefaultUniverseOnly
 class Get(base.Command):
   """Get the setting for an IAP resource."""
+
   detailed_help = {
-      'EXAMPLES':
-          """\
+      'EXAMPLES': """\
           To get the IAP setting for the resources within an organization, run:
 
             $ {command} --organization=ORGANIZATION_ID
@@ -64,6 +68,11 @@ class Get(base.Command):
 
             $ {command} --project=PROJECT_ID --resource-type=compute --service=SERVICE_ID
 
+          To get the IAP setting for a regional backend service within a project, run:
+
+            $ {command} --project=PROJECT_ID --resource-type=compute --service=SERVICE_ID
+              --region=REGION_ID
+
           """,
   }
 
